# Run the installer like this from the Terminal:
# bash installer.sh
# 
# Note: you must include "bash" even if you run this on a different shell, e.g. zsh
# 
# Uploaded to something like s3, you can run it with a single command from the Terminal:
# curl -sSL https://xlwings.s3.amazonaws.com/orbit-runtime/installer.sh | bash

set -e  # stop at errors

MINICONDA_VERSION="Miniconda3-py38_4.8.3-MacOSX-x86_64"
INSTALL_DIR="${HOME}/orbit-runtime"

# GREEN='\033[0;32m'
# RED='\033[0;31m'
# YELLOW='\033[0;33m'
# NC='\033[0m' # No Color

if [ -z "$CONDA_DEFAULT_ENV" ];then
    # We're not in an activated conda environment and installation can start
    printf "Cleaning up existing installation\n"
    rm -rf "$INSTALL_DIR" || true
    printf "Downloading Miniconda\n"
    curl -L https://repo.anaconda.com/miniconda/"$MINICONDA_VERSION".sh -o /tmp/"$MINICONDA_VERSION".sh
    printf "Installing Miniconda\n"
    bash /tmp/"$MINICONDA_VERSION".sh -u -b -p "$INSTALL_DIR"
    printf "Installing packages\n"
    "$INSTALL_DIR"/bin/conda install python=3.8 appscript=1.1.1 psutil=5.7.2 cryptography=3.1 -y
    "$INSTALL_DIR"/bin/pip install --no-deps xlwings==0.20.7
    "$INSTALL_DIR"/bin/pip install orbit-nrel==1.0.1
    printf "Installing xlwings script\n"
    "$INSTALL_DIR"/bin/xlwings runpython install
    printf "Copying Data\n"
    mkdir -p "$INSTALL_DIR"/data
    echo v0.9.0 > "$INSTALL_DIR"/data/version
    printf "Successfully installed orbit-runtime!\n"
else
    printf "Please deactivate any conda envs by running 'conda deactivate' before running this command again!\n"
    exit 1
fi
